@@ -1,11 +1,8 @@
 # flake8: NOQA
-from .jurisdiction import Jurisdiction
+from .jurisdiction import Jurisdiction, LegislativeSession
 from .division import Division
 from .people_orgs import (
     Organization,
-    OrganizationIdentifier,
-    OrganizationName,
-    OrganizationContactDetail,
     OrganizationLink,
     OrganizationSource,
     Person,
@@ -15,13 +12,8 @@ from .people_orgs import (
     PersonLink,
     PersonSource,
     Post,
-    PostContactDetail,
-    PostLink,
     Membership,
-    MembershipContactDetail,
-    MembershipLink,
 )
-from .session import LegislativeSession
 from .bill import (
     Bill,
     BillAbstract,
